# Changelog DTS 4150, DTS 4160, DTS 4210
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

Possible log types:
- [Update instructions] for essential requirements and information about the firmware update procedure
- [Added] for new features
- [Changed] for changes in existing functionality. Improvements should appear under the 'changed' section
- [Deprecated] for once-stable features removed in upcoming releases
- [Removed] for now removed features in this release
- [Fixed] for any bug fixes
- [Security] for security related changes or vulnerabilities

## [1.26.17] - 2024-02-29
### Update instructions
- DTS 4210.timecenter: Former version has to be at or above v1.18.8
### Added
- dtsmenu, MIBs: Add tDOP limit as configuration parameter
- dtsmenu, MIBs: Add tAcc (internal accuracy) limit as configuration parameter
- dtsapp: Add GNSS source timeout to `gnss.act` file
- dtsapp: Log boot reason state to dts.log on startup
- dtsapp: Catch segfault signal and log info to `/var/log/dts.log`
- dtsapp: Add consistent exception log for all processes to `/var/log/dts.log`
- Add Mars ZX3 SoM hardware information to `/ram/mars-zx3-info.txt`
### Changed
- dtsapp unittest: Change all unittest to Catch2 Version3
- dtsapp: Improve watchdog interface handling
- SyncE: Simplify ethernet interface handling
- PTP: Handle ethernet link speed changes for ptp4l instances per LAN interface
- SNMP: Improve handling of alive notification timeout calculation
### Fixed
- checklogfile.sh: fix missing PTP7 log entry --> ptp4l6.log has not been rotated
- dtsapp: Use correct size for e1 minor device read operation and validate it
- dtsapp: Fix race condition in concurrent queue used by LogPrinter and PLL/Timehandler processes
- dtsapp: Fix double open device handles
### Security
- Disable TCP timestamps


## [1.25.1] - 2023-11-02
### Update instructions
- DTS 4210.timecenter: Former version has to be at or above v1.18.8
### Fixed
- gitlab-ci: On firmware 1.24.7 kernel & devicetree from firmware 1.21.3 was released. Revert kernel and devicetree to firmware version 1.23.1.


## [1.24.7] - 2023-10-23
### Update instructions
- DTS 4210.timecenter: Former version has to be at or above v1.18.8
### Added
- New configuration parameter GNSS source drop for alarm 'GNSS Security Warning'
- MIBs: Add USB backup command
### Changed
- gitlab-ci: Download kernel as pre-built package
- Update GNSS security suite
- Avoid unwanted 'UDPv6.write(..) failed ...' log entries in dts.log during DTS 4210 extension firmware update
### Removed
- Removed 1GBit half duplex mode, it is not supported by the hardware
### Fixed
- MIBs: Set correct GNSS constellation bit mask for the supported constellations by the hardware (GNSS-Module)

## [1.23.1] - 2023-08-29
### Update instructions
- DTS 4210.timecenter: Former version has to be at or above v1.18.8
### Added
- Add GNSS security suite as licensable feature
- GNSS: Add GALILEO as configuration option (available only for hardware revision 06 or higher)
- Add 122104.00 to hardware revision 0 detection
### Changed
- NTP: Update to version 4.2.8p17
## Fixed
- Fix permission for user 'dts' for a generated diagnostic file in /ram/ folder
- DNS: Fix internal handling of resolv.conf as a file link (rcS init script, DHCPv6 script)
- dtsmenu: Allow LAN interface selection in ping menu for DTS 4150.grandmaster
- Release all resources after shadow file read operation (may fix login issues for dts user after changing the password or a parameter in general section)

## [1.22.13] - 2023-03-17
### Update instructions
- DTS 4210.timecenter: Former version has to be at or above v1.18.8
## Added
- Support the Mars ZX3 SoM hardware revision 7.1
- Devicetree: Add version and product string
- gitlab-ci: Firmware deployment with GitLab
### Changed
- VLAN: Allow VLAN ID 0
- dtsmenu: Improve PTP config texts
- PTP: Set default value for AnnounceTO to 0 for profile G8275.1 and G8275.2 to comply with profile specification
- PTP: Adjust default parameters for profile C37.238-2011 C37.238-2017 to comply with profile specification
- Enhanced IP validation covering 255.255.255.255 as invalid address
- Devicetree: Change PCA9555x access to Linux GPIO driver implementation
- u-boot: Update u-boot to version 2022.01
- u-boot: Replace autoboot stop with autoboot delay
### Fixed
- Correct device naming and commands in dtsbackup script
- PTP: Configuration changes were not always applied for ptp-configs 4-12 used by DTS 4210.timecenter. Issue was introduced with firmware v1.15.0

## [1.21.3] - 2022-08-24
### Update instructions
- DTS 4210.timecenter: Former version has to be at or above v1.18.8
### Changed
- PLL: DTS 4150 (G566N oscillator): Change pll regulation mode to source follow mode (slave mode)
- PTP: Set internal transmit timeout for hardware timestamping to default linuxptp value
- PLL: Stop offset correction on offset sign change
- GNSS: Improve hardware status data (UBX-MON) handling during initial synchronization
- Minor improvements for automated build and test
### Fixed
- TH: Set correct stratum on manual time set
- TH: Enable time outputs after manual time set
- Redundant-Link: Set always master state flag in single mode (standalone mode)
- PTP: Fix calculation of offsetScaledLogVariance variance used by BMCA defined in IEEE 1588 2008/2019 7.6.3.3.
- PTP: Set correct values for offsetScaledLogVariance for telecom profiles ITU-T G8275.1 and G8275.2
- SyncE: Improve ESMC packet generation to meet the target 1 packet/sec average
- SNMP: Fix "DTS Restart" trap not send during startup
- GNSS: Set GNSS state to valid after FPM (Fixed Position Mode) has been successful completed


## [1.20.2] - 2022-05-02
### Update instructions
- DTS 4210.timecenter: Former version has to be at or above v1.18.8
### Changed
- gitlab-ci: Changed rootfs build to detached repository
- PLL: Log all pll state changes to /var/log/pll_trim.log
- PLL: Add offset correction value to /var/log/pll_trim.log
- PLL: Change logging date format to YYMMDD instead DDMMYY for /var/log/pll_trim.log
### Fixed
- GNSS-DCF: Fix window calculation in JitterFilter for high negative values
- dtsmenu: Update timestamp info also in the general time status info section for the GNSS-DCF source
- PLL: Discard all source data after entering holdover state
- PLL: MV197 oscillator: Set 1ppb factor to 64
- PLL: G566N oscillator: Set 1ppb factor to 3
- PLL: G566N oscillator: Adjust correction factor for slow speed to 4 and fast speed to 50
- Fix invalid network configuration for LAG static modes
- TH: Update current source alarm offset in case of a time configuration change
- TH: Update current source alarm offset after initial time set
- Allow write permission for dts user on /var/local/dts/ folder used for telegram file handling


## [1.19.17] - 2021-12-23
This is the consolidated changelog since last official released version 1.18.10
### Update instructions
- DTS 4210.timecenter: Former version has to be at or above v1.18.8
### Added
- Display: Add LAN 4 interface information to display by clicking through options
- PTP: Add PTP unicast master table for PTP time source
- PTP: Add 37.xx power profiles without alternate Time Offset TLV
- GNSS: Add new log files for gnss in /ram/gnss.log and /ram/gnss-module-data.log
- GNSS-DCF(DCF-In): Add new timesource log files in /ram/gnss-dcf.log and /var/log/gnss-dcf.log
- GNSS-DCF(DCF-In): Add new timesource jitter filter implementation calculated with Standard Deviation over 10 samples
- Add general support and compatibility for hardware revision 06 and 07
- gitlab-ci: Added FPGA module as pipeline based linkage
### Changed
- GNSS: Improve GNSS reception during initial synchronization
- GNSS: Improve internal i2c communication to the GNSS module
- GNSS: Propagate internal GNSS module status more frequently
- GNSS-DCF(DCF-In): Improve overall timesource handling
- Extended GNSS logging in /var/log/gnss.log
- PLL: Change correction speed for DTS 4150 form 50ns/s to 100ns/s
- PLL: Reduce correction timeout for G566N oscillator from 1h (default) to 15min instead
- PLL: Improved calculations for MHDEV
- Powersupply: Changed internal adc-mux addressing from register based to GPIO based configuration
- linuxptp: Update to version 3.1.1
### Removed
- gitlab-ci: Removed FPGA as git submodule
- Remove dtshwtest application, it is moved to own repository
### Fixed
- dtsmenu: Fix wrong value show for internal gnss accuracy under Status->GNSS->Internal accuracy
- dtsmenu: Correct notation for GNSS-DCF time source
- dtsmenu: Set max timesource priority to 6 for DTS 4160 and DTS 4210
- dtsmenu: Allow to configure 5th source priority for DTS 4150
- dtsmenu: Show correct max page number on timeinfo page
- dtsmenu: Show same text for GNSS status parameter "internal time accuracy" as defined in snmp mibs
- dtsmenu: Show selected serial telegram for serial outputs
- PLL: Fixed max offset handling in case of time source changed
- PLL: Add check for max source deviation to oscillator intersection (offset was set to 1 instead to max)
- PLL: Fix overshoot during offset correction for DTS 4150 (osci g566n)
- TH: Fix edge case for high offset after first time set
- TH: Fix big offset alarm calculation in case a time source only provides partial nano second part only(e.g. GNSS-DCF)
- TH: Clear high offset alarm for a timesource if source is not configured
- PTP: Priority 2 parameter allows values also above 128
- GNSS: Fix sporadic GNSS timesource lost
- GNSS-DCF(DCF-In): Fix issue where GNSS-DCF(DCF-In) stops providing new samples
- GNSS-DCF(DCF-In): Do not provide a sample on second 59
- GNSS-DCF(DCF-In): Fix Alarm synch lost not set as source timeout was never reached
- GNSS-DCF(DCF-In), F-In: Apply user configuration also during startup
- LOG: Fix log rotation for file /var/log/pll_msg.log

## [1.19.17-rc] - 2021-12-23
### Fixed
- Fix clearing SynchLED, LED was set instead cleared
- Fix set and clear 10MHzSine mode

## [1.19.16-rc] - 2021-12-09
### Removed
- IO-Expander: Remove PCA9555x access with Linux GPIO driver implementation (added with 1.19.14-rc)
### Fixed
- GNSS: Fix sporadic GNSS timesource lost
- Fix timecore initialization during startup

## [1.19.15-rc] - 2021-12-03
### Added
- PTP: Enable 37.xx power profiles without alternate Time Offset TLV
### Changed
- PLL: G566N oscillator has correction timeout of 15min on default instead of 1h as all other oscillators

## [1.19.14-rc] - 2021-11-29
### Added
- Support changes for PCB revision 07
### Changed
- IO-Expander: Change PCA9555x access to Linux GPIO driver implementation
### Removed
- Remove dtshwtest application, it is moved to own repository
### Fixed
- Fix Initial time set for DTS 4210 extension boards (bug introduced in version 1.19.8-rc)

## [1.19.13-rc] - 2021-11-23
### Added
- PTP: Add PTP unicast master table for PTP time source
- PTP: Prepare parameter for C37.238 power profile
### Fixed
- Display: Fix display not show any text after startup on PCB rev. 06 and later
- dtsmenu: Show selected serial telegram for serial outputs
- dtsmenu: Show same text for GNSS status parameter "internal time accuracy" as defined in snmp mibs

## [1.19.12-rc] - 2021-10-12
### Added
- dtsapp: Add support for linuxptp 3.1.1
### Changed
- linuxptp: Update to version 3.1.1
### Fixed
- GNSS-DCF: Reduce sample filling for /var/log/gnss-dcf.log
- GNSS-DCF: Remove sample outlier logging in dts.log
- GNSS-DCF: Fix Alarm synch lost not set as source timeout was never reached

## [1.19.11-rc] - 2021-10-01
### Changed
- GNSS: Improve GNSS module reset handling by using reset-io if hardware supports it (avail. since PCB rev. 03 or higher)

### Fixed
- GNSS-DCF: In JitterFilter do not half window size in case Standard Deviation is greater then new window size
- GNSS-DCF, F-In: Apply user config also during startup


## [1.19.10-rc] - 2021-09-30
### Added
- Display: Add LAN 4 interface information to display by clicking through options
### Changed
- GNSS-DCF: Change JitterFilter calculation to Standard Deviation
### Fixed
- GNSS-DCF: Do not provide a sample on second 59

## [1.19.9-rc] - 2021-09-13
### Added
- GNSS-DCF(DCF-In): Add new timesource log file in /ram/gnss-dcf.log and /var/log/gnss-dcf.log
- GNSS-DCF(DCF-In): Add new timesource jitter filter implementation calculated with Standard Deviation over 10 samples
### Changed
- GNSS-DCF(DCF-In): Improve overall timsource handling
### Fixed
- TH: Fix big offset alarm calculation in case a time source only provides partial nano second part only(e.g. GNSS-DCF)


## [1.19.8-rc] - 2021-08-23
### Fixed
 - GNSS-DCF: Fix issue where GNSS-DCF(DCF-In) stops providing new samples
   (was still partial broken in 1.19.7)
 - dtsmenu: Set max timsource priority to 6 for DTS 4160 and DTS 4210
 - dtsmenu: Allow to configure 5th source priority for DTS 4150
 - dtsmenu: Show correct max page number on timeinfo page
 - PLL: Fix overshoot during offset correction for DTS 4150 (osci g566n)
 - TH: Fix edge case for high offset after first time set
### Security

## [1.19.7-rc] - 2021-08-14
### Added
 - gitlab-ci: Added FPGA module as pipline based linkage
### Changed
 - Powersupply: Changed internal adc-mux addressing from register based to GPIO based configuration
### Removed
 - gitlab-ci: Removed FPGA as git submodule
### Fixed
 - GNSS-DCF: Fix issue where GNSS-DCF(DCF-In) stops providing new samples
 - PLL: Add check for max source deviation to oscillator intersection (offset was set to 1 insted to max)
 - PTP: Priority 2 parameter allows values also above 128
 - LOG: Fix log rotation for file /var/log/pll_msg.log

## [1.19.6-rc] - 2021-08-05
### Fixed
 - dtsmenu: Correct notation for GNSS-DCF time source
 - Clear hight offset alarm for a timesource if source is not configured

## [1.19.4-rc] - 2021-07-14
### Added
 - Changes from release 1.19.2-rc1 also applies to this release
### Changed
 - PLL: Change correction speed for DTS 4150 form 50ns/s to 100ns/s
 - GNSS: Improve internal i2c communication to the GNSS module
 - GNSS: Propagate internal GNSS module status more frequently
### Fixed
 - PLL: Improved calculations for MHDEV
 - PLL: Fixed max offset handling in case of time source changed

## [1.18.10] - 2021-05-27
### Update instructions
- DTS 4210.timecenter: Former version has to be at or above v1.18.8
### Fixed
 - Fix dts configuration restore
 - Fix product branding for MBS factory
 - Add missing OIDs and preferences for F-In in snmp mibs for DTS 4160.grandmaster and DTS 4210.timecenter

## [1.19.2-rc1] - 2021-05-18
### Added
 - Add general support and compatibility for pcb hardware revision 06
 - Add support for NEO-M9N gnss module
 - Add support for several new oscillators for testing purpose
 - Add new log files for gnss in /ram/gnss.log and /ram/gnss-module-data.log
### Changed
 - Improve gnss reception during initial synchronization
 - Extended gnss logging in /var/log/gnss.log
### Fixed
 - dtsmenu: Fix wrong value show for internal gnss accuracy under Status->GNSS->Internal accuracy

## [1.18.8] - 2021-04-13
### Update instructions
- DTS 4210.timecenter:
  - Version 13 (V07150219.020003.010012) or earlier is installed:
    --> Please contact customer support if you have installed an earlier version then release No. 14 (V07150219.020003.010014)
  - Version 14 is installed:
    - Validate the device is running on Firmware version  V07150219.020003.010014 (release No. 14, see SR-801223.14 )
    - Install the patch named `dtsapp` as single-file-update as described in user-manual BE-801214
      The "dtsapp" patch is available together with the firmware release version No. 18 (V1.18.8)
    - Install the firmware release version 18 or later as described in the user manual BE-801214
      Important: Do NOT copy the patch "dtsapp" to device during this step; otherwise, the update of the images will be skipped
    - Validate firmware version after update. See SR-801223.18 or later for detailed version information
- DTS 4160.grandmaster: No restrictions, install the firmware as described in the user manual BE-801214
- DTS 4150.grandmaster: No restrictions, install the firmware as described in the user manual BE-801214
### Changed
 - DTS 4210: The firmware update for DTS 4210 extension boards are now executed in parallel. Dueto the update procedure takes much less time
### Fixed
 - Fix sporadic source lost/change for GNSS-DCF
 - Fix alarm not set/cleared for source F-In (frequency input)
 - Justify permission user dts, such as dtsdevice.config,  log files, ... The user dts was not always authorized access the files over scp/sftp/ftp.
 - Preserve Oscilator trim file during firmware update
 - Improve PLL for unstable sources and/or big source offsets
 - SNMP MIBs: Add missing DTS Alarm bits and precise their wording
 - DTS 4210: Fix high cpu usage for DTS 4210 extension boards issued by memory leak
 - DTS 4210: Improve firmware update for DTS 4210 extension boards
 - dtsmenu: Parameter 'Alarm delay fail. hightest source prio' can now be configured
 - dtsmenu: Precise wording for DTS Alarms


## [1.17.2] - 2021-02-04
### Update instructions
- DTS 4210.timecenter: Do not update to this version
### Added
 - Add new schema handling the firmware version. Firmware version follows now the semantic version schema.
 - New OIDs in DTS-COMMON mib for semantic firmware version 1.3.6.1.4.1.13842.4.1.3.
 - Enable checksum offload for AXI Ethernet MACs (LAN2 - LAN4)
### Changed
 - Change firmware version schema to semantic version in dtsmenu (1-Status -> 8-product-information)
 - Update also the bootlaoder (u-boot) in MBS production during firmware programming
 - Do not store trim value for oscillator in case the time source is not stable enough
### Deprecated
 - The OID 1.3.6.1.4.1.13842.4.1.2.6.0 for firmware is deprecated. Use the new OIDs under 1.3.6.1.4.1.13842.4.1.3 for firmware version
### Fixed
 - Synchronization lost alarm is set for all time sources
 - Fix GNSS timesource alarm flippering
 - Fix edge case where pll regulates the wrong way after initial time set from GNSS
 - First pll cycle must be more than 4 seconds long
 - Avoid invalid pll correction value by verify the maximum trim value against oscillator specification
 - Clear alarm for GNSS-DCF in case source is not configured
 - DTS 4150: Fix unwanted log entries in dts.log in case an ntp server query failed

## [00191020.030003.020116] - 2020-10-27
Release is for the DTS 4150.grandmaster only
### Update instructions
- DTS 4210.timecenter: Do not update to this version
- DTS 4160.grandmaster: Do not update to this version
### Added
 - Add NTP as timesource for DTS 4150
 - Add new feature for MBS production for product branding by ProductVersion.txt
### Changed
 - Update dropbaear ssh to version 2019.78
 - Update ntp to version V4.2.8p15
 - Adjust PTP profiles default parameter according their standards
 - Improve handling for timesources such as DCF-HQ, E1, F-IN
 - Enhance command set for MBS production in u-boot
 - Adjust factory defaults
 - Rename timesource DCF-HQ to GNSS-DCF
### Fixed
 - Fix clearing big offset alarm in case a source is not locked
 - Fix special case where leap second was not always correctly detected over GNSS during startup
 - Fix invalid packet loss shown in ping statistic result page
### Security
 - remove hmac-sha1-96 MAC algorithm for dropbear ssh
 - Add ntpq 'access control status' as configuration option to dtsmenu


## [1.15.0]
Internal release for MBS production
### Added
 - Add DTS 4150.grandmaster
 - Add DTS 4160a.grandmaster I
 - Add DTS 4160c.grandmaster I


## [07150219.020003.010014] - 2019-06-04
### Added
- Add config options for Alarm “Time Source Big Offset”

## [07150219.020003.010012 / 20190327] - 2019-03-27
SR-801223.13
### Changed
- First time synch adjustment for MBS production
- Improvements time source handling

## [07150219.020003.010012 / 20190215] - 2019-02-15
SR-801223.12
### Added
- New feature configure multiple timesources for DTS 4210
### Changed
- Adjustments on internal pll synchronization
- Improved DCF-In as time source
### Fixed
- Bugfix Firmware update for DTS 4160b
- Bugfix SNMPv2c with IPv6
- Minor Bugfixes & Improvements